@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import os
 
@@ -40,6 +40,7 @@ from processing.script import ScriptUtils
 class DeleteScriptAction(ContextAction):
 
     def __init__(self):
+        super().__init__()
         self.name = QCoreApplication.translate("DeleteScriptAction", "Delete Script…")
 
     def isEnabled(self):
@@ -52,7 +53,7 @@ class DeleteScriptAction(ContextAction):
                                      QMessageBox.Yes | QMessageBox.No,
                                      QMessageBox.No)
         if reply == QMessageBox.Yes:
-            filePath = ScriptUtils.findAlgorithmSource(self.itemData.__class__.__name__)
+            filePath = ScriptUtils.findAlgorithmSource(self.itemData.name())
             if filePath is not None:
                 os.remove(filePath)
                 QgsApplication.processingRegistry().providerById("script").refreshAlgorithms()
